@@ -19,43 +19,47 @@
  *                                                                         *
  ***************************************************************************/
 
-
-#include "Xmd_kmousetool.h"
 #include "kmousetool.h"
+#include "Xmd_kmousetool.h"
 #include "kmousetool.moc"
+#include "mtstroke.h"
 #include <kconfig.h>
 #include <X11/Intrinsic.h>     /* Intrinsics Definitions*/
 #include <X11/StringDefs.h>    /* Standard Name-String definitions*/
 #include <X11/extensions/xtestext1.h>    /* Standard Name-String definitions*/
 #include <X11/extensions/XTest.h>    /* Standard Name-String definitions*/
+#include <fixx11h.h>
 #include <kdialog.h>
 #include <klocale.h>
-#include <qpushbutton.h>
-#include <qpoint.h>
-#include <qnamespace.h>
+#include <QtGui/QPushButton>
+#include <QtCore/QPoint>
+#include <QtCore/qnamespace.h>
+#include <QtGui/QPixmap>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QDesktopWidget>
 #include <kmessagebox.h>
-#include <kaudioplayer.h>
 #include <kstandarddirs.h>
-#include <qsound.h>
+#include <QtGui/QSound>
 #include <kglobalsettings.h>
 #include <kdebug.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <ksystemtray.h>
+#include <QtGui/QLayout>
+#include <QtGui/QLineEdit>
+#include <QtGui/QCheckBox>
+#include <ksystemtrayicon.h>
+#include <kicon.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
+#include <kstandardguiitem.h>
 #include <knuminput.h>
-#include <kpopupmenu.h>
-#include <kaboutapplication.h>
-
-//#include <arts/soundserver.h>
+#include <kmenu.h>
+#include <kaboutapplicationdialog.h>
+#include <Phonon/MediaObject>
 #include <netwm.h>
-
+#include <kapplication.h>
 #include <iostream>
-
-#include "mtstroke.h"
+#include <QtCore/QAbstractEventDispatcher>
+#include <ktoolinvocation.h>
+#include <kglobal.h>
 
 //using namespace Arts;
 
@@ -88,18 +92,18 @@ void KMouseTool::init_vars()
 	continue_timer = 1;
 	tick_count = 0;
 	max_ticks = dwell_time+1;
-	mouse_is_down = FALSE;
+	mouse_is_down = false;
 
 	loadOptions();
 
 	// If the ~/.mousetool directory doesn't exist, create it
-//	mSoundFileName = QDir::homeDirPath();
-	mSoundFileName = locate("appdata", "sounds/mousetool_tap.wav");
-	mplayer = new KAudioPlayer(mSoundFileName);
-
+//	mSoundFileName = QDir::homePath();
+	mSoundFileName = KStandardDirs::locate("appdata", "sounds/mousetool_tap.wav");
+	mplayer = Phonon::createPlayer(Phonon::AccessibilityCategory);
+	mplayer->setParent(this);
 
 	// find application file
-	appfilename = locate("exe", "kmousetool");
+	appfilename = KStandardDirs::locate("exe", "kmousetool");
 
 	// find the user's autostart directory
 	autostartdirname = KGlobalSettings::autostartPath();
@@ -147,7 +151,7 @@ void KMouseTool::timerEvent( QTimerEvent * )
 		return;
 
 	if (!continue_timer) {
-		killTimers();
+		QAbstractEventDispatcher::instance()->unregisterTimers(this);
 		return;
 	}
 
@@ -202,13 +206,13 @@ void KMouseTool::normalClick()
 	if (smart_drag_on) {
 		if (!mouse_is_down) {
 			LeftDn();
-			mouse_is_down = TRUE;
+			mouse_is_down = true;
 			tick_count = 0;
 			playTickSound();
 		}
 		else if (mouse_is_down) {
 			LeftUp();
-			mouse_is_down = FALSE;
+			mouse_is_down = false;
 			tick_count = max_ticks;
 		}
 	}
@@ -225,6 +229,7 @@ void KMouseTool::playTickSound()
 	if (!playSound)
 	return;
 
+	mplayer->setCurrentSource(mSoundFileName);
 	mplayer->play();
 	// This is a bit slow.
 //	KAudioPlayer::play(mSoundFileName);
@@ -242,7 +247,7 @@ void KMouseTool::playTickSound()
 
 //	if(sound_server.isNull())
 //		return;
-//	sound_server.play(mSoundFileName.latin1());
+//	sound_server.play(mSoundFileName.toLatin1());
 
 	// Another approach is to try using QSound.
 	// QSound depends on Network Audio Server, which doesn't seem to work on my Debian Woody system.
@@ -250,8 +255,11 @@ void KMouseTool::playTickSound()
 //	QSound::play(mSoundFileName);
 }
 
-KMouseTool::KMouseTool(QWidget *parent, const char *name) : KMouseToolUI(parent, name)
+KMouseTool::KMouseTool(QWidget *parent, const char *name) :
+        QWidget(parent)
 {
+        setupUi(this);
+        setObjectName(name);
 	init_vars();
 	resetSettings();
 
@@ -264,18 +272,16 @@ KMouseTool::KMouseTool(QWidget *parent, const char *name) : KMouseToolUI(parent,
 	connect(cbStart, SIGNAL(stateChanged(int)), this, SLOT(settingsChanged()));
 
 	connect(buttonStartStop, SIGNAL(clicked()), this, SLOT(startStopSelected()));
-	buttonDefault->setGuiItem(KStdGuiItem::defaults());
+	buttonDefault->setGuiItem(KStandardGuiItem::defaults());
 	connect(buttonDefault, SIGNAL(clicked()), this, SLOT(defaultSelected()));
 	connect(buttonReset, SIGNAL(clicked()), this, SLOT(resetSelected()));
-	buttonApply->setGuiItem(KStdGuiItem::apply());
+	buttonApply->setGuiItem(KStandardGuiItem::apply());
 	connect(buttonApply, SIGNAL(clicked()), this, SLOT(applySelected()));
-	buttonHelp->setGuiItem(KStdGuiItem::help());
+	buttonHelp->setGuiItem(KStandardGuiItem::help());
 	connect(buttonHelp, SIGNAL(clicked()), this, SLOT(helpSelected()));
-	buttonClose->setGuiItem(KStdGuiItem::close());
+	buttonClose->setGuiItem(KStandardGuiItem::close());
 	connect(buttonClose, SIGNAL(clicked()), this, SLOT(closeSelected()));
-#if KDE_VERSION >= KDE_MAKE_VERSION (3,1,90)
-	buttonQuit->setGuiItem(KStdGuiItem::quit());
-#endif // KDE 3.2
+	buttonQuit->setGuiItem(KStandardGuiItem::quit());
 	connect(buttonQuit, SIGNAL(clicked()), this, SLOT(quitSelected()));
 
 	// When we first start, it's nice to not click immediately.
@@ -291,7 +297,7 @@ KMouseTool::KMouseTool(QWidget *parent, const char *name) : KMouseToolUI(parent,
 	connect(trayIcon, SIGNAL(helpSelected()), this, SLOT(helpSelected()));
 	connect(trayIcon, SIGNAL(quitSelected()), this, SLOT(quitSelected()));
 
-	aboutDlg = new KAboutApplication (0, "KMouseToolDlg", false);
+	aboutDlg = new KAboutApplicationDialog (KGlobal::mainComponent().aboutData());
 }
 
 KMouseTool::~KMouseTool()
@@ -304,34 +310,34 @@ KMouseTool::~KMouseTool()
 // these should be moved to a separate file.
 void LeftClick()
 {
-	XTestFakeButtonEvent(display, 1, TRUE, 0);
-	XTestFakeButtonEvent(display, 1, FALSE, 0);
+	XTestFakeButtonEvent(display, 1, true, 0);
+	XTestFakeButtonEvent(display, 1, false, 0);
 }
 
 void DoubleClick()
 {
-	XTestFakeButtonEvent(display, 1, TRUE, 0);
-	XTestFakeButtonEvent(display, 1, FALSE, 100);
-	XTestFakeButtonEvent(display, 1, TRUE, 200);
-	XTestFakeButtonEvent(display, 1, FALSE, 300);
+	XTestFakeButtonEvent(display, 1, true, 0);
+	XTestFakeButtonEvent(display, 1, false, 100);
+	XTestFakeButtonEvent(display, 1, true, 200);
+	XTestFakeButtonEvent(display, 1, false, 300);
 }
 
 void RightClick()
 {
-	XTestFakeButtonEvent(display, 3, TRUE, 0);
-	XTestFakeButtonEvent(display, 3, FALSE, 0);
+	XTestFakeButtonEvent(display, 3, true, 0);
+	XTestFakeButtonEvent(display, 3, false, 0);
 }
 
 
 void LeftDn()
 {
-	XTestFakeButtonEvent(display, 1, TRUE, 0);
+	XTestFakeButtonEvent(display, 1, true, 0);
 }
 
 
 void LeftUp()
 {
-	XTestFakeButtonEvent(display, 1, FALSE, 0);
+	XTestFakeButtonEvent(display, 1, false, 0);
 }
 
 
@@ -397,13 +403,13 @@ void KMouseTool::setAutostart (bool start)
 
 	if (start) {
 		if (!fi.exists())  			// if it doesn't exist, make it
-		cmd.sprintf("ln -s %s %s", appfilename.latin1(), autostartdirname.latin1());
+		cmd = QString("ln -s %1 %2").arg(appfilename).arg(autostartdirname);
 	}
 	else {
 	if (fi.exists()) 			// if it exists, delete it
-		cmd.sprintf("rm -f %s", sym.latin1());
+		cmd = QString("rm -f %s").arg(sym);
 	}
-	system(cmd.ascii());
+	system(cmd.toAscii());
 }
 
 bool KMouseTool::applySettings()
@@ -438,24 +444,24 @@ bool KMouseTool::applySettings()
 // Save options to kmousetoolrc file
 void KMouseTool::loadOptions()
 {
-	kapp->config()->setGroup("UserOptions");
+	KConfigGroup cfg = KGlobal::config()->group("UserOptions");
 
-	playSound = kapp->config()->readBoolEntry("AudibleClick",false);
-	smart_drag_on = kapp->config()->readBoolEntry("SmartDrag",false);
+	playSound = cfg.readEntry("AudibleClick", false);
+	smart_drag_on = cfg.readEntry("SmartDrag", false);
 
-	dwell_time = kapp->config()->readNumEntry("DwellTime",5);
-	drag_time = kapp->config()->readNumEntry("DragTime",3);
-	min_movement = kapp->config()->readNumEntry("Movement",5);
-	strokesEnabled = kapp->config()->readBoolEntry("strokesEnabled",false);
+	dwell_time = cfg.readEntry("DwellTime",5);
+	drag_time = cfg.readEntry("DragTime",3);
+	min_movement = cfg.readEntry("Movement",5);
+	strokesEnabled = cfg.readEntry("strokesEnabled", false);
 
 	QPoint p;
-	int x = kapp->config()->readNumEntry("x",0);
-	int y = kapp->config()->readNumEntry("y",0);
+	int x = cfg.readEntry("x",0);
+	int y = cfg.readEntry("y",0);
 	p.setX(x);
 	p.setY(y);
 	move(p);
 
-	mousetool_is_running = kapp->config()->readBoolEntry("MouseToolIsRunning",false);
+	mousetool_is_running = cfg.readEntry("MouseToolIsRunning", false);
 	display = XOpenDisplay(NULL);
 }
 
@@ -466,20 +472,20 @@ void KMouseTool::saveOptions()
 	int x = p.x();
 	int y = p.y();
 
-	kapp->config()->setGroup("ProgramOptions");
-	kapp->config()->writeEntry("Version", KMOUSETOOL_VERSION);
-	kapp->config()->setGroup("UserOptions");
-	kapp->config()->writeEntry("x", x);
-	kapp->config()->writeEntry("y", y);
-	kapp->config()->writeEntry("strokesEnabled", strokesEnabled);
-	kapp->config()->writeEntry("IsMinimized", isHidden());
-	kapp->config()->writeEntry("DwellTime", dwell_time);
-	kapp->config()->writeEntry("DragTime", drag_time);
-	kapp->config()->writeEntry("Movement", min_movement);
-	kapp->config()->writeEntry("SmartDrag", smart_drag_on);
-	kapp->config()->writeEntry("AudibleClick", playSound);
-	kapp->config()->writeEntry("MouseToolIsRunning", mousetool_is_running);
-	kapp->config()->sync();
+	KConfigGroup cfg = KGlobal::config()->group("ProgramOptions");
+	cfg.writeEntry("Version", KMOUSETOOL_VERSION);
+	cfg = KGlobal::config()->group("UserOptions");
+	cfg.writeEntry("x", x);
+	cfg.writeEntry("y", y);
+	cfg.writeEntry("strokesEnabled", strokesEnabled);
+	cfg.writeEntry("IsMinimized", isHidden());
+	cfg.writeEntry("DwellTime", dwell_time);
+	cfg.writeEntry("DragTime", drag_time);
+	cfg.writeEntry("Movement", min_movement);
+	cfg.writeEntry("SmartDrag", smart_drag_on);
+	cfg.writeEntry("AudibleClick", playSound);
+	cfg.writeEntry("MouseToolIsRunning", mousetool_is_running);
+	cfg.sync();
 }
 
 void KMouseTool::updateStartStopText()
@@ -548,7 +554,7 @@ void KMouseTool::applySelected()
 // Buttons at the bottom of the dialog
 void KMouseTool::helpSelected()
 {
-	kapp->invokeHelp();
+	KToolInvocation::invokeHelp();
 }
 
 void KMouseTool::closeSelected()
@@ -558,7 +564,8 @@ void KMouseTool::closeSelected()
 		int answer = KMessageBox::questionYesNoCancel (this,
 			i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing the configuration window or discard the changes?"),
 			i18n("Closing Configuration Window"),
-			KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
+			KStandardGuiItem::apply(), KStandardGuiItem::discard(),
+			KStandardGuiItem::cancel(), "AutomaticSave");
 		if (answer == KMessageBox::Yes)
 			applySettings();
 		else if (answer == KMessageBox::No)
@@ -577,7 +584,8 @@ void KMouseTool::quitSelected()
 		int answer = KMessageBox::questionYesNoCancel (this,
 			i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before quitting KMousetool or discard the changes?"),
 			i18n("Quitting KMousetool"),
-			KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
+			KStandardGuiItem::apply(), KStandardGuiItem::discard(),
+			KStandardGuiItem::cancel(), "AutomaticSave");
 		if (answer == KMessageBox::Yes)
 			applySettings();
 		if (answer != KMessageBox::Cancel)
@@ -598,7 +606,7 @@ void KMouseTool::configureSelected()
 {
 	show();
 	raise();
-	setActiveWindow();
+	activateWindow();
 }
 
 void KMouseTool::aboutSelected()
@@ -608,17 +616,20 @@ void KMouseTool::aboutSelected()
 
 
 
-KMouseToolTray::KMouseToolTray (QWidget *parent, const char *name) : KSystemTray (parent, name)
+KMouseToolTray::KMouseToolTray (QWidget *parent, const char *name) : KSystemTrayIcon (parent)
 {
-	startStopId = contextMenu()->insertItem (i18n("&Start"), this, SIGNAL(startStopSelected()));
-	contextMenu()->insertSeparator();
-	contextMenu()->insertItem (KGlobal::iconLoader()->loadIcon("configure", KIcon::Small),
-	                           i18n("&Configure KMouseTool..."), this, SIGNAL(configureSelected()));
-	contextMenu()->insertSeparator();
-	contextMenu()->insertItem (KGlobal::iconLoader()->loadIcon("contents", KIcon::Small),
-	                           i18n("KMousetool &Handbook"), this, SIGNAL(helpSelected()));
-	contextMenu()->insertItem (KGlobal::iconLoader()->loadIcon("kmousetool", KIcon::Small),
-	                           i18n("&About KMouseTool"), this, SIGNAL(aboutSelected()));
+	setObjectName(name);
+
+	startStopAct = contextMenu()->addAction (i18n("&Start"), this, SIGNAL(startStopSelected()));
+	contextMenu()->addSeparator();
+        QAction* act;
+	act = contextMenu()->addAction (i18n("&Configure KMouseTool..."), this, SIGNAL(configureSelected()));
+        act->setIcon(KIcon("configure"));
+	contextMenu()->addSeparator();
+	act = contextMenu()->addAction (i18n("KMousetool &Handbook"), this, SIGNAL(helpSelected()));
+        act->setIcon(KIcon("help-contents"));
+	act = contextMenu()->addAction (i18n("&About KMouseTool"), this, SIGNAL(aboutSelected()));
+        act->setIcon(KIcon("kmousetool"));
 }
 
 KMouseToolTray::~KMouseToolTray() {
@@ -626,16 +637,16 @@ KMouseToolTray::~KMouseToolTray() {
 
 void KMouseToolTray::updateStartStopText(bool mousetool_is_running)
 {
-	QPixmap icon;
+	QIcon icon;
 
 	if (mousetool_is_running) {
-		contextMenu()->changeItem (startStopId, i18n("&Stop"));
-		icon = KGlobal::iconLoader()->loadIcon("kmousetool_on", KIcon::Small);
+                startStopAct->setText(i18n("&Stop"));
+		icon = KIconLoader::global()->loadIcon("kmousetool_on", KIconLoader::Small);
 	}
 	else {
-		contextMenu()->changeItem (startStopId, i18n("&Start"));
-		icon = KGlobal::iconLoader()->loadIcon("kmousetool_off", KIcon::Small);
+                startStopAct->setText(i18n("&Start"));
+		icon = KIconLoader::global()->loadIcon("kmousetool_off", KIconLoader::Small);
 	}
-	setPixmap (icon);
+	setIcon (icon);
 	show();
 }
