@@ -22,6 +22,10 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// FilterMgr includes.
+#include "filtermgr.h"
+#include "filtermgr.moc"
+
 // Qt includes
 #include <QtCore/QCoreApplication>
 
@@ -34,15 +38,11 @@
 #include <klocale.h>
 #include <kservicetypetrader.h>
 
-// FilterMgr includes.
-#include "filtermgr.h"
-#include "filtermgr.moc"
-
 /**
  * Constructor.
  */
 FilterMgr::FilterMgr( QObject *parent) :
-    KttsFilterProc(parent)
+    KttsFilterProc(parent, QVariantList())
 {
     // kDebug() << "FilterMgr::FilterMgr: Running";
     m_state = fsIdle;
@@ -73,8 +73,9 @@ bool FilterMgr::init()
     // Load each of the filters and initialize.
     KSharedConfig::Ptr pConfig = KSharedConfig::openConfig( "kttsdrc" );
     KConfigGroup config( pConfig, "General");
+    KConfig* rawconfig = new KConfig("kttsdrc");
     QStringList filterIDsList = config.readEntry("FilterIDs", QStringList());
-    // kDebug() << "FilterMgr::init: FilterIDs = " << filterIDsList;
+     kDebug() << "FilterMgr::init: FilterIDs = " << filterIDsList;
     // If no filters have been configured, automatically configure the standard SBD.
     if (filterIDsList.isEmpty())
     {
@@ -114,11 +115,11 @@ bool FilterMgr::init()
             }
             if (config.readEntry("Enabled",false) || config.readEntry("IsSBD",false))
             {
-                // kDebug() << "FilterMgr::init: filterID = " << filterID;
+                kDebug() << "FilterMgr::init: filterID = " << filterID;
                 KttsFilterProc* filterProc = loadFilterPlugin( desktopEntryName );
                 if ( filterProc )
                 {
-                    filterProc->init( pConfig->group( groupName ) );
+                    filterProc->init( rawconfig, groupName );
                     m_filterList.append( filterProc );
                 }
                 if (config.readEntry("DocType").contains("html") ||
