@@ -22,6 +22,10 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// PluginConf includes.
+#include "filterconf.h"
+#include "filterconf.moc"
+
 // C++ library includes.
 #include <stdlib.h>
 #include <sys/param.h>
@@ -34,19 +38,15 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-// PluginConf includes.
-#include "filterconf.h"
-#include "filterconf.moc"
-
 /**
 * Constructor 
 */
-KttsFilterConf::KttsFilterConf( QWidget *parent, const char *name) : QWidget(parent){
-    setObjectName(name);
+KttsFilterConf::KttsFilterConf( QWidget *parent, const QVariantList &) : QWidget(parent){
+    //setObjectName(name);
     // kDebug() << "KttsFilterConf::KttsFilterConf: Running";
-    QString systemPath(getenv("PATH"));
+    QString systemPath(qgetenv("PATH"));
     // kDebug() << "Path is " << systemPath;
-    m_path = systemPath.split( ":");
+    m_path = systemPath.split( ':');
 }
 
 /**
