@@ -21,6 +21,11 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// FestivalInt includes.
+#include "festivalintconf.h"
+#include "festivalintconf.moc"
+#include "festivalintproc.h"
+
 // C++ includes.
 #include <math.h>
 
@@ -48,11 +53,6 @@
 // KTTS includes.
 #include "testplayer.h"
 
-// FestivalInt includes.
-#include "festivalintproc.h"
-#include "festivalintconf.h"
-#include "festivalintconf.moc"
-
 /** Constructor */
 FestivalIntConf::FestivalIntConf( QWidget* parent, const QStringList& /*args*/) :
     PlugInConf(parent, "festivalintconf")
@@ -472,7 +472,7 @@ void FestivalIntConf::scanVoices()
         KIcon maleIcon("male");
         KIcon femaleIcon("female");
         QStringList::ConstIterator itEnd = m_supportedVoiceCodes.constEnd();
-        for(QStringList::ConstIterator it = m_supportedVoiceCodes.begin(); it != itEnd; ++it )
+        for(QStringList::ConstIterator it = m_supportedVoiceCodes.constBegin(); it != itEnd; ++it )
         {
             QString code = *it;
             bool found = false;
@@ -695,13 +695,13 @@ void FestivalIntConf::slotSelectVoiceCombo_activated()
 // with alpha = 1000/(log(200)-log(50))
 
 int FestivalIntConf::percentToSlider(int percentValue) {
-    double alpha = 1000 / (log(200) - log(50));
-    return (int)floor (0.5 + alpha * (log(percentValue)-log(50)));
+    double alpha = 1000 / (log(200.0) - log(50.0));
+    return (int)floor (0.5 + alpha * (log((float)percentValue)-log(50.0)));
 }
 
 int FestivalIntConf::sliderToPercent(int sliderValue) {
-    double alpha = 1000 / (log(200) - log(50));
-    return (int)floor(0.5 + exp (sliderValue/alpha + log(50)));
+    double alpha = 1000 / (log(200.0) - log(50.0));
+    return (int)floor(0.5 + exp (sliderValue/alpha + log(50.0)));
 }
 
 void FestivalIntConf::volumeBox_valueChanged(int percentValue) {
